# EInvoiceProcessType

E-Invoice process type

## Enum

* `CLEARANCE` (value: `'Clearance'`)

* `CLEARANCEWITHCANCELLATION` (value: `'ClearanceWithCancellation'`)

* `POSTAUDIT` (value: `'PostAudit'`)

* `PEPPOLNETWORK` (value: `'PEPPOLNetwork'`)

* `UNKNOWN` (value: `'Unknown'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


